@@ -18,6 +18,10 @@ import numpy as np
 class MainWindow(tkinter.Tk):
     
     def __init__(self):
+        ### Location of the static files
+        static_addr = GBARpy.__file__
+        static_addr = path.split(static_addr)[0]
+        static_addr = path.join(static_addr,'static')
         
         ### Fenetre principale
         tkinter.Tk.__init__(self)
@@ -56,14 +60,16 @@ class MainWindow(tkinter.Tk):
         self.export.grid(row=2,column=0)
         self.savedAs = tkinter.Label(self.frame0_c, textvariable=self.savedAsText)
         self.savedAs.grid(row=2,column=1)
+        """
         
-        img = Image.open("img/GBAR_logo.png")
+        add = static_addr = path.join(static_addr,"GBAR_logo.png")
+        img = Image.open(add)
         img = img.resize((100, 100), Image.ANTIALIAS)
         img = ImageTk.PhotoImage(img)
         panel = tkinter.Label(self.frame0, image=img)
         panel.image = img
         panel.pack(side='right')
-        """
+
         
         ### Cadre 1 Importation de l'image
         self.frame1 = tkinter.Frame(self, width=400, height=400,
@@ -78,7 +84,8 @@ class MainWindow(tkinter.Tk):
         self.frame2.pack(side='right')
         
         ### MCP parameters
-        self.mcp_param = import_config("other/BGT_in.mcp")
+        add = static_addr = path.join(static_addr,"BGT_in.mcp")
+        self.mcp_param = import_config(add)
        
 
 
